@@ -1,4 +1,4 @@
-# Copyright (C) 2004 Laurent Sansonetti
+# Copyright (C) 2004-2005 Laurent Sansonetti
 #
 # Alexandria is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -17,8 +17,8 @@
 
 module Alexandria
     class Book
-        attr_accessor :title, :authors, :isbn, :publisher, :edition, 
-                      :rating, :notes
+        attr_accessor :title, :authors, :isbn, :publisher, :edition, :rating, 
+                      :notes, :loaned, :loaned_since, :loaned_to, :saved_ident
 
         DEFAULT_RATING = 0 
 
@@ -29,8 +29,19 @@ module Alexandria
             @publisher = publisher
             @edition = edition
             @notes = ""
+            @saved_ident = ident
+        end
+
+        def ident
+            if @isbn
+                return @isbn
+            else
+                return @title.hash.to_s
+            end
+        end
+        
+        def loaned? 
+            (loaned or false)
         end
     end
 end
-
-   
